@@ -93,7 +93,6 @@ pub use self::chats_nearby::*;
 pub use self::check_chat_username_result::*;
 pub use self::check_sticker_set_name_result::*;
 pub use self::closed_vector_path::*;
-pub use self::color_replacement::*;
 pub use self::connected_website::*;
 pub use self::connected_websites::*;
 pub use self::connection_state::*;
@@ -407,7 +406,6 @@ mod chats_nearby;
 mod check_chat_username_result;
 mod check_sticker_set_name_result;
 mod closed_vector_path;
-mod color_replacement;
 mod connected_website;
 mod connected_websites;
 mod connection_state;
